@@ -183,15 +183,15 @@ var NAVTREEINDEX0 =
 "av1__loopfilter_8h_source.html":[14,0,2,0,1],
 "bitstream_8h_source.html":[14,0,2,2,1],
 "block_8h.html":[14,0,2,2,2],
-"block_8h.html#a602ec0e36e0a86c78c15fe547c275e1f":[14,0,2,2,2,28],
-"block_8h.html#a6e06ec17c5b54de9fd8d829fb2a305b7":[14,0,2,2,2,31],
-"block_8h.html#a73de00e232811ea3f0290dcc425f86d5":[14,0,2,2,2,26],
-"block_8h.html#a8c18014b69f341bf169c4a5656ee2978":[14,0,2,2,2,29],
-"block_8h.html#aa775a8f85de55be3f4c2e39285d706c9":[14,0,2,2,2,32],
-"block_8h.html#aaaf8a99ac7b3d643d9b95ea1da93f6c2":[14,0,2,2,2,33],
-"block_8h.html#ab657b1844dfce1e763e658761bb0952c":[14,0,2,2,2,27],
-"block_8h.html#ad4666c85680e16e181fe9b46c1957274":[14,0,2,2,2,30],
-"block_8h.html#ae0a195ea38f0a04ad9a9d6d7ed5bb754":[14,0,2,2,2,25],
+"block_8h.html#a602ec0e36e0a86c78c15fe547c275e1f":[14,0,2,2,2,29],
+"block_8h.html#a6e06ec17c5b54de9fd8d829fb2a305b7":[14,0,2,2,2,32],
+"block_8h.html#a73de00e232811ea3f0290dcc425f86d5":[14,0,2,2,2,27],
+"block_8h.html#a8c18014b69f341bf169c4a5656ee2978":[14,0,2,2,2,30],
+"block_8h.html#aa775a8f85de55be3f4c2e39285d706c9":[14,0,2,2,2,33],
+"block_8h.html#aaaf8a99ac7b3d643d9b95ea1da93f6c2":[14,0,2,2,2,34],
+"block_8h.html#ab657b1844dfce1e763e658761bb0952c":[14,0,2,2,2,28],
+"block_8h.html#ad4666c85680e16e181fe9b46c1957274":[14,0,2,2,2,31],
+"block_8h.html#ae0a195ea38f0a04ad9a9d6d7ed5bb754":[14,0,2,2,2,26],
 "block_8h_source.html":[14,0,2,2,2],
 "blockd_8h_source.html":[14,0,2,0,2],
 "cdef_8h_source.html":[14,0,2,0,3],
@@ -208,12 +208,18 @@ var NAVTREEINDEX0 =
 "encode__strategy_8h.html":[14,0,2,2,3],
 "encode__strategy_8h_source.html":[14,0,2,2,3],
 "encoder_8h.html":[14,0,2,2,4],
-"encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f":[14,0,2,2,4,37],
-"encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda":[14,0,2,2,4,39],
-"encoder_8h.html#a246db68993252fe81c1e5a911575efb4":[14,0,2,2,4,38],
-"encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f":[14,0,2,2,4,36],
-"encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718":[14,0,2,2,4,35],
-"encoder_8h.html#ae37f210917b9733abc7ca81445427d71":[14,0,2,2,4,34],
+"encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f":[14,0,2,2,4,39],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055":[14,0,2,2,4,42],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a0387b2a2bbc01b142f3716c18a97fe9d":[14,0,2,2,4,42,1],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a6e437058362eef3c17fc5c856202dee3":[14,0,2,2,4,42,2],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a6f0f4239b7fc9f98980631093f885cc0":[14,0,2,2,4,42,3],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a7ab17ad52ce554037df368d89cef2c02":[14,0,2,2,4,42,0],
+"encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda":[14,0,2,2,4,41],
+"encoder_8h.html#a246db68993252fe81c1e5a911575efb4":[14,0,2,2,4,40],
+"encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f":[14,0,2,2,4,37],
+"encoder_8h.html#a9af93120431b9d96ca04670151ea562c":[14,0,2,2,4,38],
+"encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718":[14,0,2,2,4,36],
+"encoder_8h.html#ae37f210917b9733abc7ca81445427d71":[14,0,2,2,4,35],
 "encoder_8h_source.html":[14,0,2,2,4],
 "encoder_guide.html":[8],
 "encoder_guide.html#architecture_av1_structure":[8,0,1],
@@ -243,11 +249,5 @@ var NAVTREEINDEX0 =
 "encoder_guide.html#architecture_enc_rate_ctrl_data":[8,6,0],
 "encoder_guide.html#architecture_enc_rate_ctrl_options":[8,6,1],
 "encoder_guide.html#architecture_enc_rc_loop":[8,6,3],
-"encoder_guide.html#architecture_enc_speed_quality":[8,4],
-"encoder_guide.html#architecture_enc_src_proc":[8,5],
-"encoder_guide.html#architecture_enc_tpl":[8,8],
-"encoder_guide.html#architecture_enc_tpl_algoritms":[8,8,1],
-"encoder_guide.html#architecture_enc_tpl_config":[8,8,0],
-"encoder_guide.html#architecture_enc_tpl_keyfun":[8,8,2],
-"encoder_guide.html#architecture_enc_tx_search":[8,12]
+"encoder_guide.html#architecture_enc_speed_quality":[8,4]
 };
